import json
from .client import MinioBaseResource

class MinioPolicy(MinioBaseResource):
    def create(self, name, policy):
        payload = {
            'name': name,
            'policy': policy,
        }
        return self.client.post("/policies", data=json.dumps(payload)).json()

    def delete(self, name):
        return self.client.delete("/policy", params={'name': name})

    def find(self, name):
        result = self.client.get("/policies").json()
        items = result.get("policies")
        if not items:
            return
        for item in items:
            if item.get("name") == name:
                return item


import json
from .client import MinioBaseResource


class MinioUser(MinioBaseResource):
    def create(self, access_key, secret_key):
        payload = {
            'accessKey': access_key,
            'secretKey': secret_key,
            'policies': [],
            'groups': [],
        }
        return self.client.post("/users", data=json.dumps(payload)).json()

    def delete(self, access_key):
        params = {
            'name': access_key,
        }
        return self.client.delete("/user", params=params)

    def find(self, access_key):
        result = self.client.get("/users").json()
        items = result.get("users")
        if not items:
            return
        for item in items:
            if item.get("accessKey") == access_key:
                return item
        return

    def set_policy(self, access_key, policy_name):
        payload = {
            "entityName": access_key,
            "entityType": "user",
            "name": [policy_name,],
        }
        return self.client.put("/set-policy", data=json.dumps(payload))


import unittest

from minio_console import MinioConsoleClient


class TestClient(unittest.TestCase):

    def test_connection_refused(self):
        try:
            MinioConsoleClient("http://localhost:12345", "admin", "admin")
            self.fail("Expected exception")
        except Exception as e:
            self.assertIn("Connection refused", str(e))


if __name__ == '__main__':
    unittest.main()



import requests
import json

class MinioConsoleClient:
    def __init__(self, url, username, password):
        # docs: https://github.com/minio/console/blob/master/swagger-console.yml
        self.url = url + "/api/v1"
        self.username = username
        self.password = password
        self.token = self._login()
        self.headers = {
            'Content-Type': 'application/json',
            'Cookie': self.token,
        }

    def _login(self):
        payload = {
            'accessKey': self.username,
            'secretKey': self.password
        }
        headers = {
            'Content-Type': 'application/json'
        }
        response = requests.request("POST", self.url + "/login", headers=headers, data=json.dumps(payload))
        response.raise_for_status()
        return response.headers.get("set-cookie").split(";")[0]

    def _do(self, method, path, params=None, data=None):
        response = requests.request(method, self.url + path, params=params, data=data, headers=self.headers)
        response.raise_for_status()
        return response

    def get(self, path, params=None, data=None):
        return self._do("GET", path, params=params, data=data)

    def delete(self, path, params=None, data=None):
        return self._do("DELETE", path, params=params, data=data)

    def post(self, path, params=None, data=None):
        return self._do("POST", path, params=params, data=data)

    def put(self, path, params=None, data=None):
        return self._do("PUT", path, params=params, data=data)


class MinioBaseResource:
    def __init__(self, client):
        self.client = client


import json
from .client import MinioBaseResource


class MinioBucket(MinioBaseResource):
    def create(self, name):
        payload = {
            'name': name,
        }
        return self.client.post("/buckets", data=json.dumps(payload))

    def delete(self, name):
        return self.client.delete("/buckets/" + name)

    def find(self, name):
        result = self.client.get("/buckets").json()
        items = result.get("buckets")
        if not items:
            return
        for item in items:
            if item.get("name") == name:
                return item
        return